@@ -37,19 +37,13 @@ int mdecrypt_ofb(int td, void *ciphertext, int len);
 int init_mcrypt_ofb( const int algorithm, void * key, int lenofkey, void *IV);
 
 void gen_key(void *keyword, void *salt, size_t salt_size, size_t key_size,
-             unsigned char *password);
+             unsigned char *password, int plen);
 
 # define BLOWFISH 0
 # define DES 1 
 # define TripleDES 2
 # define ThreeWAY 3
 # define GOST 4
-
-#ifdef MCRYPT2
-# define CRYPT 50
-# define DES_COMPAT 51
-#endif
-
 # define SAFER64 6
 # define SAFER128 7
 # define CAST128 8
